@@ -56,22 +56,25 @@ class OMS:
             if self.exchange.has.get("unWatchOrders"):
                 await self.exchange.un_watch_orders(self.symbol)
 
-    async def create_orders(self, orders: List[OrderRequest], params={}):
+    async def create_orders(self, orders: List[OrderRequest], symbol: str, params={}):
+        """
+        symbol param is required as hyperliquid does not return a symbol in the response when order is created
+        """
         if not hasattr(self.exchange, "create_orders_ws"):
             raise NotImplementedError("Batch create order not supported")
 
-        orders = await self.exchange.create_orders_ws(orders, params)
-        for order in orders:
+        response_orders = await self.exchange.create_orders_ws(orders, params)
+        for order in response_orders:
             if order["id"]:
                 log.debug(
                     "Created %s order %s with status=%s",
-                    order["symbol"],
+                    symbol,
                     order["id"],
                     order["status"],
                 )
                 o = Order(
                     order_id=str(order["id"]),
-                    symbol=order["symbol"],
+                    symbol=symbol,
                     side=order["side"],
                     price=order["price"],
                     amount=order["amount"],
